==> staging-demo-20260207_095928.tar.gz: var/www/html/staging-demo/var/tmp/twig/8f/8f37537bf7d3a8b4d43c7001e6eb7690.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticUser/Security/base.html.twig */
class __TwigTemplate_ecab4b065ff4d0651bdfa404e24bcdf4 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
            'content' => [$this, 'block_content'],
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "
<!DOCTYPE html>
<html>
<head>
    <meta charset=\"UTF-8\" />
    <title>Cause Buzz</title>
    <meta name=\"robots\" content=\"noindex, nofollow\" />
    <meta name=\"viewport\" content=\"width=device-width, initial-scale=1, maximum-scale=1\">
    <link rel=\"icon\" type=\"image/x-icon\" href=\"/themes/system/CoreBundle/Assets/img/favicon.ico\" />
    <link rel=\"apple-touch-icon\" href=\"/themes/system/CoreBundle/Assets/img/favicon.ico\" />
    ";
        // line 11
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputSystemStylesheets();
        // line 12
        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/script.html.twig");
        // line 13
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputHeadDeclarations();
        yield "
</head>
<body>
<section id=\"main\" role=\"main\">
    <div class=\"container ml-a mr-a\" style=\"margin-top:100px;\">
        <div class=\"row\">
            <div class=\"col-lg-4 col-lg-offset-4\">
                <div class=\"panel\" name=\"form-login\">
                    <div class=\"panel-body\">
                        <div class=\"mautic-logo img-circle mb-md text-center\">
                            <img style=\"width: 150px; height: 150px;\" src=\"/themes/system/CoreBundle/Assets/img/logo-cut.png\">
                        </div>
                        <div id=\"main-panel-flash-msgs\">";
        // line 26
        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Notification/flashes.html.twig");
        // line 27
        yield "</div>
                        ";
        // line 28
        yield from $this->unwrap()->yieldBlock('content', $context, $blocks);
        // line 29
        yield "                    </div>
                </div>
            </div>
        </div>
         <div class=\"row\">
            <div class=\"col-lg-4 col-lg-offset-4 text-center text-muted\">
   \t\t © ";
        // line 35
        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Twig\Extension\CoreExtension']->formatDate("now", "Y"), "html", null, true);
        yield " Cause Buzz. Alle Rechte vorbehalten.
            </div>
        </div>
    </div>
</section>
";
        // line 40
        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Mautic\CoreBundle\Twig\Extension\SecurityExtension']->getContext(), "html", null, true);
        yield "
</body>
</html>
";
        yield from [];
    }

    // line 28
    /**
     * @return iterable<null|scalar|\Stringable>
     */
    public function block_content(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticUser/Security/base.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  106 => 28,  97 => 40,  89 => 35,  81 => 29,  79 => 28,  76 => 27,  74 => 26,  59 => 13,  57 => 12,  55 => 11,  43 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticUser/Security/base.html.twig", "/var/www/html/staging-demo/themes/system/UserBundle/Resources/views/Security/base.html.twig");
    }
}

==> staging-demo-20260213_145710.tar.gz: var/www/html/staging-demo/var/tmp/twig/8f/8f37537bf7d3a8b4d43c7001e6eb7690.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticUser/Security/base.html.twig */
class __TwigTemplate_ecab4b065ff4d0651bdfa404e24bcdf4 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
            'pageTitle' => [$this, 'block_pageTitle'],
            'content' => [$this, 'block_content'],
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "
<!DOCTYPE html>
<html>
<head>
    <meta charset=\"UTF-8\" />
    <title>";
        // line 6
        yield from $this->unwrap()->yieldBlock('pageTitle', $context, $blocks);
        yield "</title>
    <meta name=\"robots\" content=\"noindex, nofollow\" />
    <meta name=\"viewport\" content=\"width=device-width, initial-scale=1, maximum-scale=1\">
    <link rel=\"icon\" type=\"image/x-icon\" href=\"/themes/system/CoreBundle/Assets/img/favicon.ico\" />
    <link rel=\"apple-touch-icon\" href=\"/themes/system/CoreBundle/Assets/img/favicon.ico\" />
    ";
        // line 11
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputSystemStylesheets();
        // line 12
        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/script.html.twig");
        // line 13
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputHeadDeclarations();
        yield "
</head>
<body>
<section id=\"main\" role=\"main\">
    <div class=\"container ml-a mr-a\" style=\"margin-top:100px;\">
        <div class=\"row\">
            <div class=\"col-lg-4 col-lg-offset-4\">
                <div class=\"panel\" name=\"form-login\">
                    <div class=\"panel-body\">
                        <div class=\"mautic-logo img-circle mb-md text-center\">
                            <img style=\"width: 150px; height: 150px;\" src=\"/themes/system/CoreBundle/Assets/img/logo-cut.png\">
                        </div>
                        <div id=\"main-panel-flash-msgs\">";
        // line 26
        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Notification/flashes.html.twig");
        // line 27
        yield "</div>
                        ";
        // line 28
        yield from $this->unwrap()->yieldBlock('content', $context, $blocks);
        // line 29
        yield "                    </div>
                </div>
            </div>
        </div>
         <div class=\"row\">
            <div class=\"col-lg-4 col-lg-offset-4 text-center text-muted\">
   \t\t © ";
        // line 35
        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Twig\Extension\CoreExtension']->formatDate("now", "Y"), "html", null, true);
        yield " Cause Buzz. Alle Rechte vorbehalten.
            </div>
        </div>
    </div>
</section>
";
        // line 40
        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Mautic\CoreBundle\Twig\Extension\SecurityExtension']->getContext(), "html", null, true);
        yield "
</body>
</html>
";
        yield from [];
    }

    // line 6
    /**
     * @return iterable<null|scalar|\Stringable>
     */
    public function block_pageTitle(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        yield "Cause Buzz";
        yield from [];
    }

    // line 28
    /**
     * @return iterable<null|scalar|\Stringable>
     */
    public function block_content(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticUser/Security/base.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  121 => 28,  110 => 6,  101 => 40,  93 => 35,  85 => 29,  83 => 28,  80 => 27,  78 => 26,  63 => 13,  61 => 12,  59 => 11,  51 => 6,  44 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticUser/Security/base.html.twig", "/var/www/html/staging-demo/themes/system/UserBundle/Resources/views/Security/base.html.twig");
    }
}
